@@ -1,4 +1,4 @@
-#' @title Repeated Spatial Cross Validation Resampling
+#' @title (blockCV) Repeated spatial block resampling
 #'
 #' @template rox_spcv_block
 #'
@@ -32,7 +32,6 @@
 #' }
 ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
   inherit = mlr3::Resampling,
-
   public = list(
 
     #' @field blocks `sf | list of sf objects`\cr
@@ -41,7 +40,9 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
     blocks = NULL,
 
     #' @description
-    #' Create an "coordinate-based" repeated resampling instance.
+    #' Create an "spatial block" repeated resampling instance.
+    #'
+    #' For a list of available arguments, please see [blockCV::spatialBlock].
     #' @param id `character(1)`\cr
     #'   Identifier for the resampling strategy.
     initialize = function(id = "repeated_spcv_block") {
@@ -60,7 +61,8 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
           custom_check = function(x) {
             checkmate::check_class(x, "RasterLayer",
               null.ok = TRUE)
-          })
+          }
+        )
       ))
 
       ps$values = list(folds = 10L, repeats = 1L)
@@ -69,7 +71,6 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
         param_set = ps,
         man = "mlr3spatiotempcv::mlr_resamplings_repeated_spcv_block"
       )
-
     },
 
     #' @description Translates iteration numbers to fold number.
@@ -77,7 +78,7 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
     #'   Iteration number.
     folds = function(iters) {
       iters = assert_integerish(iters, any.missing = FALSE, coerce = TRUE)
-      ((iters - 1L) %% as.integer(self$param_set$values$repeats)) + 1L
+      ((iters - 1L) %% as.integer(self$param_set$values$folds)) + 1L
     },
 
     #' @description Translates iteration numbers to repetition number.
@@ -157,7 +158,6 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
       invisible(self)
     }
   ),
-
   active = list(
 
     #' @field iters `integer(1)`\cr
@@ -168,7 +168,6 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
       as.integer(pv$repeats) * as.integer(pv$folds)
     }
   ),
-
   private = list(
     .sample = function(ids, coords, crs) {
 
@@ -217,9 +216,7 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
       map_dtr(inds, function(i) {
         i$resampling
       })
-
     },
-
     .get_train = function(i) {
       i = as.integer(i) - 1L
       folds = as.integer(self$param_set$values$folds)
@@ -228,7 +225,6 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
       ii = data.table(rep = rep, fold = seq_len(folds)[-fold])
       self$instance[ii, "row_id", on = names(ii), nomatch = 0L][[1L]]
     },
-
     .get_test = function(i) {
       i = as.integer(i) - 1L
       folds = as.integer(self$param_set$values$folds)
