@@ -1,4 +1,4 @@
-#' @title Spatial Cross Validation Resampling
+#' @title (sperrorest) Coordinate-based k-means clustering
 #'
 #' @template rox_spcv_coords
 #'
@@ -27,7 +27,9 @@ ResamplingSpCVCoords = R6Class("ResamplingSpCVCoords",
 
   public = list(
     #' @description
-    #' Create an "Environmental Block" resampling instance.
+    #' Create an "coordinate-based" repeated resampling instance.
+    #'
+    #' For a list of available arguments, please see [sperrorest::partition_cv].
     #' @param id `character(1)`\cr
     #'   Identifier for the resampling strategy.
     initialize = function(id = "spcv_coords") {
@@ -37,7 +39,8 @@ ResamplingSpCVCoords = R6Class("ResamplingSpCVCoords",
       ps$values = list(folds = 10L)
       super$initialize(
         id = id,
-        param_set = ps
+        param_set = ps,
+        man = "mlr3spatiotempcv::mlr_resamplings_spcv_coords"
       )
     },
 
@@ -62,18 +65,14 @@ ResamplingSpCVCoords = R6Class("ResamplingSpCVCoords",
       self$task_hash = task$hash
       self$task_nrow = task$nrow
       invisible(self)
-    }
-  ),
-
+    }),
   active = list(
     #' @field iters `integer(1)`\cr
     #'   Returns the number of resampling iterations, depending on the
     #'   values stored in the `param_set`.
     iters = function() {
       self$param_set$values$folds
-    }
-  ),
-
+    }),
   private = list(
     .sample = function(ids, coords) {
       inds = kmeans(coords, centers = self$param_set$values$folds)
@@ -90,9 +89,7 @@ ResamplingSpCVCoords = R6Class("ResamplingSpCVCoords",
     .get_train = function(i) {
       self$instance[!list(i), "row_id", on = "fold"][[1L]]
     },
-
     .get_test = function(i) {
       self$instance[list(i), "row_id", on = "fold"][[1L]]
-    }
-  )
+    })
 )
