@@ -3,7 +3,7 @@ loadNamespace("mlr3")
 
 prepare_autoplot = function(resampling_type, task = NULL, ...) {
   if (is.null(task)) {
-    task = test_make_twoclass()
+    task = test_make_twoclass_task()
   }
   rsp = rsmp(resampling_type, ...)
   rsp$instantiate(task)
