@@ -1,11 +1,11 @@
 test_that("coordinates can be used as features", {
-  task = test_make_twoclass(coords_as_features = TRUE)
+  task = test_make_twoclass_task(coords_as_features = TRUE)
 
   expect_names(c("x", "y"), subset.of = task$feature_names)
 })
 
 test_that("printing works", {
-  task = test_make_twoclass()
+  task = test_make_twoclass_task()
 
   expect_output(print(task))
   expect_data_table(task$coordinates())
@@ -19,7 +19,7 @@ test_that("Supplying a non-spatio temporal task gives descriptive error message"
 })
 
 test_that("coordinates can be used as features", {
-  task = test_make_twoclass(coords_as_features = TRUE)
+  task = test_make_twoclass_task(coords_as_features = TRUE)
 
   expect_names(c("x", "y"), subset.of = task$feature_names)
 })
